from app.core.graph.graph_operations import connect_graph

def production_draw_graph(id, type):
    """
    根据节点ID和类型绘制生产线图谱
    
    Args:
        id: 节点ID
        type: 节点类型(data_model, data_resource, data_metric)
        
    Returns:
        dict: 包含节点、连线和根节点ID的图谱数据
    """
    # 数据模型
    if type == "data_model":
        cql = """
        MATCH (n)
        WHERE id(n) = $nodeId AND labels(n)[0] = "data_model"
        MATCH (n)-[r:connection]-(m:meta_node)
        OPTIONAL MATCH (n)-[r2:clean_model]-(d:data_standard)
        OPTIONAL MATCH (d)-[r3:clean_model]-(m)
        WITH 
             collect({from: toString(id(n)), to: toString(id(m)), text: "包含"}) AS line1,
             collect({from: toString(id(n)), to: toString(id(d)), text: "清洗"}) AS line2,
             collect({from: toString(id(d)), to: toString(id(m)), text: "清洗"}) AS line3,
             collect({id: toString(id(n)), text: n.name, type: "model"}) AS node1,
             collect({id: toString(id(m)), text: m.name}) AS node2,
             collect({id: toString(id(d)), text: d.name, type: "standard"}) AS node3,n
        WITH apoc.coll.toSet(line1 + line2 + line3) AS lines,
             apoc.coll.toSet(node1 + node2 + node3) AS nodes,
             toString(id(n)) as res
        RETURN lines,nodes,res
        """
        data = connect_graph.run(cql, nodeId=id).data()
        res = {}
        for item in data:
            res = {
                "nodes": [record for record in item['nodes'] if record['id']],
                "lines": [record for record in item['lines'] if record['from'] and record['to']],
                "rootId": item['res'],
            }

        return res
    # 数据资源
    elif type == "data_resource":
        cql = """
        MATCH (n)
        WHERE id(n) = $nodeId AND labels(n)[0] = "data_resource"
        MATCH (n)-[r:connection]-(m:meta_node)
        OPTIONAL MATCH (n)-[r2:clean_resource]-(d:data_standard)
        OPTIONAL MATCH (d)-[r3:clean_resource]-(m)
        WITH 
            collect({from: toString(id(n)), to: toString(id(m)), text: "包含"}) AS lines1,
            collect({from: toString(id(n)), to: toString(id(d)), text: "清洗"}) AS lines2,
            collect({from: toString(id(d)), to: toString(id(m)), text: "清洗"}) AS lines3,
            collect({id: toString(id(n)), text: n.name, type: "resource"}) AS nodes1,
            collect({id: toString(id(m)), text: m.name}) AS nodes2,
            collect({id: toString(id(d)), text: d.name, type: "standard"}) AS nodes3,n     
        WITH 
            apoc.coll.toSet(lines1 + lines2 + lines3) AS lines,
            apoc.coll.toSet(nodes1 + nodes2 + nodes3) AS nodes,
            toString(id(n)) AS res       
        RETURN lines, nodes, res
        """
        data = connect_graph.run(cql, nodeId=id).data()
        res = {}
        for item in data:
            res = {
                "nodes": [record for record in item['nodes'] if record['id']],
                "lines": [record for record in item['lines'] if record['from'] and record['to'] ],
                "rootId": item['res'],
            }

        return res
    # 数据指标
    elif type == "data_metric":
        cql = """
                MATCH (n)
                WHERE id(n) = $nodeId AND labels(n)[0] = "data_metric"
                MATCH (n)-[r:connection]-(m:meta_node)
                WITH collect({from: toString(id(n)), to: toString(id(m)), text: "处理"}) AS line1,
                    collect({id: toString(id(n)), text: n.name, type: "etric"}) AS node1,
                    collect({id: toString(id(m)), text: m.name}) AS node2,n
                WITH apoc.coll.toSet(line1) AS lines,
                    apoc.coll.toSet(node1 + node2) AS nodes,
                    toString(id(n)) as res
                RETURN lines,nodes,res
                """
        data = connect_graph.run(cql, nodeId=id).data()
        res = {}
        for item in data:
            res = {
                "nodes": [record for record in item['nodes'] if record['id']],
                "lines": [record for record in item['lines'] if record['from'] and record['to']],
                "rootId": item['res'],
            }

        return res 